<?php

namespace Litecms\TestPackage\Providers;

use Illuminate\Support\ServiceProvider;

class TestPackageServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'test_package');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'test_package');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.test_package', function ($app) {
            return $this->app->make('Litecms\TestPackage\TestPackage');
        });

                // Bind TestPackage to repository
        $this->app->bind(
            'Litecms\TestPackage\Interfaces\TestPackageRepositoryInterface',
            \Litecms\TestPackage\Repositories\Eloquent\TestPackageRepository::class
        );

        $this->app->register(\Litecms\TestPackage\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\TestPackage\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.test_package'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/test_package.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/test_package')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/test_package')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
